@@ -1,5 +1,7 @@
 const content1 = `first line\r\nsecond line\r\nthird line`;
-const content2 = `first line\nsecond line\nthird line`;
+const content2 = `first line
+second line
+third line`;
 console.log({
     content1,
     content2
